@@ -28,6 +28,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 #include "WPAudioReader.h"
 #include "VorbisAudioReader.h"
 #include "ResampleAudioReader.h"
+#include "Utils.h"
 
 #include <QString>
 
@@ -141,7 +142,7 @@ AbstractAudioReader* AbstractAudioReader::create_audio_reader(const QString& fil
 #endif
 		
 		if (newReader && !newReader->is_valid()) {
-			PERROR("new %s reader is invalid! (channels: %d, frames: %d)", (const char *)(newReader->decoder_type().toUtf8()), newReader->get_num_channels(), newReader->get_nframes());
+			PERROR("new %s reader is invalid! (channels: %d, frames: %d)", QS_C(newReader->decoder_type()), newReader->get_num_channels(), newReader->get_nframes());
 			delete newReader;
 			newReader = 0;
 		}
@@ -169,7 +170,7 @@ AbstractAudioReader* AbstractAudioReader::create_audio_reader(const QString& fil
 	}
 	
 	if (newReader && !newReader->is_valid()) {
-		PERROR("new %s reader is invalid! (channels: %d, frames: %d)", (const char *)(newReader->decoder_type().toUtf8()), newReader->get_num_channels(), newReader->get_nframes());
+		PERROR("new %s reader is invalid! (channels: %d, frames: %d)", QS_C(newReader->decoder_type()), newReader->get_num_channels(), newReader->get_nframes());
 		delete newReader;
 		newReader = 0;
 	}
@@ -196,8 +197,8 @@ void DecodeBuffer::check_buffers_capacity(uint size, uint channels)
 	if (meanvalue < destinationBufferSize && ((meanvalue + 256) < destinationBufferSize) && !(destinationBufferSize == size)) {
 		m_smallerReadCounter++;
 		if (m_smallerReadCounter > 8) {
-// 			Force recreation of the buffers;
-			destinationBufferSize = readBufferSize = 0;
+			delete_destination_buffers();
+			delete_readbuffer();
 			m_bufferSizeCheckCounter = m_smallerReadCounter = 0;
 			m_totalCheckSize = 0;
 		}
@@ -217,7 +218,7 @@ void DecodeBuffer::check_buffers_capacity(uint size, uint channels)
 		}
 			
 		destinationBufferSize = size;
-// 		printf("id %lld :: resizing destination to %.3f KB\n", id, (float)size*4/1024);
+// 		printf("resizing destination to %.3f KB\n", (float)size*4/1024);
 	}
 		
 	if (readBufferSize < (size*m_channels)) {
@@ -232,12 +233,6 @@ void DecodeBuffer::check_buffers_capacity(uint size, uint channels)
 void DecodeBuffer::delete_destination_buffers()
 {
 	if (destination) {
-		uint destChannelcount = (sizeof(destination) / sizeof(destination[0]));
-		if (destChannelcount != m_channels) {
-			PERROR("destination channel count != m_channels: dest channel %d, m_channels %d", destChannelcount, m_channels);
-			m_channels = destChannelcount;
-		}
-		
 		for (uint chan = 0; chan < m_channels; chan++) {
 			delete [] destination[chan];
 		}
@@ -246,6 +241,7 @@ void DecodeBuffer::delete_destination_buffers()
 		
 		destination = 0;
 		destinationBufferSize = 0;
+		m_channels = 0;
 	}
 }
 
