@@ -33,22 +33,15 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 Import::Import(const QString& fileName)
 	: Command("")
 {
-	m_fileName = fileName;
-	m_clip = 0;
-	m_track = 0;
-	m_silent = false;
-	m_hasPosition = false;
-	m_initialLength = TimeRef();
+	init(0, fileName);
 }
 
 
 Import::Import(Track* track, const TimeRef& length, bool silent)
 	: Command(track, "")
 {
-	m_track = track;
-	m_clip = 0;
+	init(track, "");
 	m_silent = silent;
-	m_hasPosition = false;
 	m_initialLength = length;
 	
 	if (!m_silent) {
@@ -62,26 +55,32 @@ Import::Import(Track* track, const TimeRef& length, bool silent)
 Import::Import(Track* track, const QString& fileName)
 	: Command(track, tr("Import Audio File"))
 {
-	m_track = track;
-	m_clip = 0;
-	m_fileName = fileName;
-	m_silent = false;
-	m_hasPosition = false;
-	m_initialLength = TimeRef();
+	init(track, fileName);
 }
 
 Import::Import(Track* track, const QString& fileName, const TimeRef& position)
 	: Command(track, tr("Import Audio File"))
 {
-	m_track = track;
-	m_clip = 0;
-	m_fileName = fileName;
-	m_silent = false;
-	m_initialLength = TimeRef();
+	init(track, fileName);
 	m_hasPosition = true;
 	m_position = position;
 }
 
+void Import::init(Track* track, const QString& fileName)
+{
+	m_clip = 0;
+	m_source = 0;
+	m_position = TimeRef();
+	m_silent = false;
+	m_hasPosition = false;
+	m_fileName = fileName;
+	m_track = track;
+	m_initialLength = TimeRef();
+
+}
+
+
+
 Import::~Import()
 {}
 
@@ -94,10 +93,13 @@ int Import::prepare_actions()
 		m_fileName = tr("Silence");
 		create_audioclip();
 	} else if (m_fileName.isEmpty()) {
+		QString allFiles = tr("All files (*)");
+		QString activeFilter = tr("Audio files (*.wav *.flac *.ogg *.mp3 *.wv *.w64)");
 		m_fileName = QFileDialog::getOpenFileName(0,
 				tr("Import audio source"),
 				pm().get_project()->get_import_dir(),
-				tr("All files (*);;Audio files (*.wav *.flac *.ogg *.mp3 *.wv *.w64)"));
+				allFiles + ";;" + activeFilter,
+				&activeFilter);
 		
 		int splitpoint = m_fileName.lastIndexOf("/") + 1;
 		QString dir = m_fileName.left(splitpoint - 1);
@@ -140,12 +142,13 @@ void Import::create_audioclip()
 	Q_ASSERT(m_track);
 	m_clip = resources_manager()->new_audio_clip(m_name);
 	resources_manager()->set_source_for_clip(m_clip, m_source);
-	m_clip->set_song(m_track->get_song());
+	m_clip->set_sheet(m_track->get_sheet());
 	m_clip->set_track(m_track);
 	
 	TimeRef startLocation;
 	if (!m_hasPosition) {
-		if (AudioClip* lastClip = (AudioClip*)m_track->get_cliplist().last()) {
+		if (!m_track->get_cliplist().isEmpty()) {
+			AudioClip* lastClip = m_track->get_cliplist().last();
 			startLocation = lastClip->get_track_end_location();
 		}
 	} else {
@@ -194,5 +197,3 @@ int Import::undo_action()
 
 
 // eof
-
-
