@@ -86,7 +86,7 @@ int PCommand::do_action()
                 }
 
                 // covers both the float and double types!
-                if (m_doValue.type() == QVariant::Double) {
+                if (m_doValue.type() == QVariant::Double || m_doValue.type() == QMetaType::Float) {
                             bool ok;
                             if (QMetaObject::invokeMethod(m_contextitem, m_slot, Qt::DirectConnection, Q_ARG(float, m_doValue.toDouble(&ok)))) {
                                     return 1;
@@ -112,7 +112,7 @@ int PCommand::undo_action()
 		}
 		
                 // covers both the float and double types!
-                if (m_undoValue.type() == QVariant::Double) {
+                if (m_undoValue.type() == QVariant::Double || m_doValue.type() == QMetaType::Float) {
                             bool ok;
                             if (QMetaObject::invokeMethod(m_contextitem, m_slot, Qt::DirectConnection, Q_ARG(float, m_undoValue.toDouble(&ok)))) {
                                     return 1;
