@@ -13,3 +13,5 @@
 #include "AudioClipExternalProcessing.h"
 #include "ArmTracks.h"
 #include "RemoveClip.h"
+#include "Scroll.h"
+#include "Crop.h"
