@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2006 Remon Sijrier 
+Copyright (C) 2017 Remon Sijrier
 
 This file is part of Traverso
 
@@ -17,7 +17,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: Tsar.h,v 1.4 2008/02/11 10:11:52 r_sijrier Exp $
 */
 
 #ifndef TSAR_H
@@ -43,7 +42,7 @@ $Id: Tsar.h,v 1.4 2008/02/11 10:11:52 r_sijrier Exp $
 	if ( ! retrievedsignalindex ) { \
 		/* the signal index seems to have an offset of 4, so we have to substract 4 from */ \
 		/* the value returned by caller->metaObject()->indexOfMethod*/  \
-		retrievedsignalindex = cal->metaObject()->indexOfMethod(#signalSignature) - 4; \
+        retrievedsignalindex = cal->metaObject()->indexOfMethod(#signalSignature) - cal->metaObject()->methodOffset(); \
 		Q_ASSERT(retrievedsignalindex >= 0); \
 	} \
 	event.signalindex = retrievedsignalindex; \
@@ -63,7 +62,6 @@ struct TsarEvent {
 	QObject* 	caller;
 	void*		argument;
 	int		slotindex;
-	void*		_a[];
 
 // Used for the signal emiting stuff
 	int signalindex;
