@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006 Remon Sijrier 
+    Copyright (C) 2005-2008 Remon Sijrier 
  
     This file is part of Traverso
  
@@ -17,12 +17,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  
-    $Id: AudioClipManager.cpp,v 1.20 2007/11/05 15:49:29 r_sijrier Exp $
 */
  
 #include "AudioClipManager.h"
 
-#include "Song.h"
+#include "Sheet.h"
 #include "AudioClip.h"
 #include "ResourcesManager.h"
 #include "ProjectManager.h"
@@ -32,13 +31,13 @@
 #include "Utils.h"
 #include "Debugger.h"
 
-AudioClipManager::AudioClipManager( Song* song )
-	: ContextItem(song)
+AudioClipManager::AudioClipManager( Sheet* sheet )
+	: ContextItem(sheet)
 {
 	PENTERCONS;
-	m_song = song;
-	set_history_stack( m_song->get_history_stack() );
-	lastLocation = TimeRef();
+	m_sheet = sheet;
+	set_history_stack( m_sheet->get_history_stack() );
+	m_lastLocation = TimeRef();
 }
 
 AudioClipManager::~ AudioClipManager( )
@@ -46,6 +45,44 @@ AudioClipManager::~ AudioClipManager( )
 	PENTERDES;
 }
 
+
+QDomNode AudioClipManager::get_state(QDomDocument doc, bool istemplate)
+{
+	QDomElement managerNode = doc.createElement("ClipManager");
+	QDomElement globalSelection = doc.createElement("GlobalSelection");
+	
+	QStringList selectedClips;
+	foreach(AudioClip* clip, m_clipselection) {
+		selectedClips << QString::number(clip->get_id());
+	}
+	
+	globalSelection.setAttribute("clips",  selectedClips.join(";"));
+	
+	managerNode.appendChild(globalSelection);
+	
+	return managerNode;
+}
+
+int AudioClipManager::set_state(const QDomNode & node)
+{
+	QDomElement e = node.firstChildElement("GlobalSelection");
+	
+	QStringList selectionList = e.attribute("clips", "").split(";");
+	
+	for (int i=0; i<selectionList.size(); ++i) {
+		qint64 id = selectionList.at(i).toLongLong();
+		foreach(AudioClip* clip, m_clips) {
+			if (clip->get_id() == id) {
+				add_to_selection(clip);
+			}
+		}
+	}
+	
+	return 1;
+
+}
+
+
 void AudioClipManager::add_clip( AudioClip * clip )
 {
 	PENTER;
@@ -56,10 +93,9 @@ void AudioClipManager::add_clip( AudioClip * clip )
 	
 	m_clips.append( clip );
 	
-	connect(clip, SIGNAL(trackEndLocationChanged()), this, SLOT(update_last_frame()));
-	connect(clip, SIGNAL(positionChanged(Snappable*)), m_song->get_snap_list(), SLOT(mark_dirty(Snappable*)));
+	connect(clip, SIGNAL(positionChanged()), this, SLOT(update_last_frame()));
 	
-	m_song->get_snap_list()->mark_dirty(clip);
+	m_sheet->get_snap_list()->mark_dirty();
 	update_last_frame();
 	resources_manager()->mark_clip_added(clip);
 }
@@ -67,13 +103,14 @@ void AudioClipManager::add_clip( AudioClip * clip )
 void AudioClipManager::remove_clip( AudioClip * clip )
 {
 	PENTER;
-	disconnect(clip, SIGNAL(positionChanged(Snappable*)), m_song->get_snap_list(), SLOT(mark_dirty(Snappable*)));
 	if (m_clips.removeAll(clip) == 0) {
 		PERROR("Clip %s was not in my list, couldn't remove it!!", QS_C(clip->get_name()));
 		return;
 	}
 	
-	m_song->get_snap_list()->mark_dirty(clip);
+	remove_from_selection(clip);
+	
+	m_sheet->get_snap_list()->mark_dirty();
 	update_last_frame();
 	resources_manager()->mark_clip_removed(clip);
 }
@@ -83,55 +120,40 @@ void AudioClipManager::update_last_frame( )
 {
 	PENTER;
 	
-	lastLocation = TimeRef();
+	m_lastLocation = TimeRef();
 	
 	foreach(AudioClip* clip, m_clips) {
-		if (clip->get_track_end_location() >= lastLocation)
-			lastLocation = clip->get_track_end_location();
+		if (clip->get_track_end_location() >= m_lastLocation)
+			m_lastLocation = clip->get_track_end_location();
 	}
 	
-	emit m_song->lastFramePositionChanged();
+	emit m_sheet->lastFramePositionChanged();
 }
 
-const TimeRef& AudioClipManager::get_last_location() const
+TimeRef AudioClipManager::get_last_location() const
 {
-	return lastLocation;
+	return m_lastLocation;
 }
 
-void AudioClipManager::get_selected_clips_state( QList< AudioClip * > & list )
+void AudioClipManager::get_selected_clips( QList< AudioClip * > & list )
 {
-	foreach(AudioClip* clip, clipselection) {
+	foreach(AudioClip* clip, m_clipselection) {
 		list.append(clip);
 	}
 }
 
-void AudioClipManager::set_selected_clips_state( QList< AudioClip * > & list )
-{
-	clipselection.clear();
-	
-	foreach(AudioClip* clip, m_clips) {
-		clip->set_selected(false);
-	}
-	
-	foreach(AudioClip* clip, list) {
-		add_to_selection( clip );
-	}
-}
-
 void AudioClipManager::remove_from_selection( AudioClip * clip )
 {
-	int index = clipselection.indexOf( clip );
-	
-	if (index >= 0) {
-		clipselection.takeAt( index );
+	if (m_clipselection.contains(clip)) {
+		m_clipselection.removeAll(clip);
 		clip->set_selected( false );
 	}
 }
 
 void AudioClipManager::add_to_selection( AudioClip * clip )
 {
-	if ( ! clipselection.contains( clip ) ) {
-		clipselection.append( clip );
+	if ( ! m_clipselection.contains( clip ) ) {
+		m_clipselection.append( clip );
 		clip->set_selected( true );
 	}
 }
@@ -152,26 +174,23 @@ void AudioClipManager::select_clip(AudioClip* clip)
 	PENTER;
 	
 	foreach(AudioClip* c, m_clips) {
-		if (c == clip) {
-			continue;
-		}
-		remove_from_selection( c );
-	}
-	
-
-	if (clip->is_selected()) {
-		remove_from_selection(clip);
-	} else {
-		add_to_selection(clip);
+		remove_from_selection(c);
 	}
 	
+	add_to_selection(clip);
 }
 
-QList<AudioClip* >* AudioClipManager::get_clip_list()
+QList<AudioClip* > AudioClipManager::get_clip_list() const
 {
-	return &m_clips;
+	return m_clips;
 }
 
+bool AudioClipManager::is_clip_in_selection(AudioClip* clip)
+{
+	return m_clipselection.contains(clip);
+}
+
+
 /****************************** SLOTS ***************************/
 /****************************************************************/
 
@@ -180,16 +199,13 @@ Command* AudioClipManager::select_all_clips()
 {
 	PENTER;
 	
+	if (m_clipselection.size()) {
+		return new ClipSelection(m_clips, this, "remove_from_selection", tr("Selection: Remove Clip"));
+	}
+		
 	return new ClipSelection(m_clips, this, "add_to_selection", tr("Selection: Add Clip"));
 }
 
-Command* AudioClipManager::deselect_all_clips()
-{
-	PENTER;
-	
-	return new ClipSelection(m_clips, this, "remove_from_selection", tr("Selection: Remove Clip"));
-}
-
 Command* AudioClipManager::invert_clip_selection()
 {
 	PENTER;
@@ -197,14 +213,3 @@ Command* AudioClipManager::invert_clip_selection()
 	return new ClipSelection(m_clips, this, "toggle_selected", tr("Selection: Invert"));
 }
 
-Command* AudioClipManager::delete_selected_clips()
-{
-	PENTER;
-	CommandGroup* group = new CommandGroup(this, tr("Remove Clip(s)"));
-	foreach(AudioClip* clip, clipselection) {
-		group->add_command(clip->get_track()->remove_clip(clip));
-	}
-	return group;
-}
-
-//eof
