@@ -23,21 +23,12 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 #ifndef COMMAND_PLUGIN_H
 #define COMMAND_PLUGIN_H
 
-#include <QtPlugin>
 #include <Command.h>
 #include <QStringList>
 #include <QHash>
 #include <QVariant>
 
-class CommandInterface
-{
-public:
-	virtual ~CommandInterface() {}
-	virtual Command* create(QObject* obj, const QString& command, QVariantList arguments) = 0;
-};
-
-Q_DECLARE_INTERFACE(CommandInterface, "org.traversodaw.Command.CommandInterface/1.0");
-
+#include "CommandInterface.h"
 
 /**
  * \class CommandPlugin
@@ -48,7 +39,8 @@ Q_DECLARE_INTERFACE(CommandInterface, "org.traversodaw.Command.CommandInterface/
 class CommandPlugin : public QObject, public CommandInterface
 {
 	Q_OBJECT
-	Q_INTERFACES(CommandInterface);
+    Q_PLUGIN_METADATA(IID "org.traversodaw.Command.CommandInterface")
+    Q_INTERFACES(CommandInterface);
 
 public:
 	virtual ~CommandPlugin() {}
@@ -60,7 +52,7 @@ public:
 	 * @param arguments List of arguments which can be parsed by the to be created Command object.
 	 * @return On success a Command object, the caller takes authorship, or 0 on failure.
  */
-	virtual Command* create(QObject* obj, const QString& command, QVariantList arguments) = 0;
+    virtual Command* create(QObject* obj, const QString& command, QVariantList arguments) {return 0;}
 	
 	virtual QStringList commands() const {
 		return QStringList(m_dict.keys());
