@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2005-2006 Remon Sijrier 
+Copyright (C) 2005-2007 Remon Sijrier 
 
 This file is part of Traverso
 
@@ -17,40 +17,61 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: ContextItem.h,v 1.4 2006/06/26 23:57:48 r_sijrier Exp $
 */
+
 #ifndef CONTEXTITEM_H
 #define CONTEXTITEM_H
 
 #include <QObject>
-#include "HistoryStack.h"
+
+class Command;
+class QUndoStack;
+class QUndoGroup;
+
+/**
+ * \class ContextItem
+ * \brief Interface class for objects (both core and gui) that operate in a 'Soft Selection'
+ *	
+	Each core object that has/can have a visual representation should inherit from this class.
+
+	Only core objects that inherit this class need to set the historystack which <br />
+	they need to create/get themselves.
+ */
 
 class ContextItem : public QObject
 {
 	Q_OBJECT
 public:
-	ContextItem(ContextItem* item=0, QObject* parent=0);
-	~ContextItem();
-
-	ContextItem* get_context() const
-	{
-		return m_contextItem;
-	}
+	ContextItem(QObject* parent)
+		: QObject(parent)
+		, m_hs(0)
+		, m_contextItem(0) {}
 	
-	HistoryStack* get_history_stack() const;
-
-	void set_history_stack(HistoryStack* hs);
+	ContextItem()
+		: QObject()
+		, m_hs(0)
+		, m_contextItem(0) {}
 	
-	void set_context_item(ContextItem* item);
-	
-	friend class Tsar;
+	~ContextItem() {}
 
+	ContextItem* get_context() const {return m_contextItem;}
+	
+	QUndoStack* get_history_stack() const {return m_hs;}
+	qint64 get_id() const {return m_id;}
+
+	void set_history_stack(QUndoStack* hs) {m_hs = hs;}
+
+	void set_context_item(ContextItem* item) {m_contextItem = item;}
+
+	
 protected:
-	HistoryStack* m_hs;
+	QUndoStack* m_hs;
+	qint64 m_id;
 
 private:
 	ContextItem* m_contextItem;
 
+	friend class Tsar;
 };
 
 #endif
