@@ -114,25 +114,28 @@ public:
 	void process(uint channel, audio_sample_t* buffer, nframes_t frames);
 	int prepare_processing(int rate);
 	int finish_processing();
-	int calculate_peaks(int chan, float** buffer, int zoomLevel, TimeRef startlocation, int count);
+	int calculate_peaks(int chan, float** buffer, TimeRef startlocation, int peakDataCount, qreal framesPerPeak);
 
 	void close();
 	
 	void start_peak_loading();
 
 	audio_sample_t get_max_amplitude(TimeRef startlocation, TimeRef endlocation);
+	
+	static QHash<int, int>* cache_index_lut();
+	static int max_zoom_value();
 
 private:
 	ReadSource* 	m_source;
 	bool 		m_peaksAvailable;
 	bool		m_permanentFailure;
 	bool		m_interuptPeakBuild;
+	static QHash<int, int> chacheIndexLut;
 	
 	struct ProcessData {
 		ProcessData() {
 			normValue = peakUpperValue = peakLowerValue = 0;
 			processBufferSize = progress = normProcessedFrames = normDataCount = 0;
-			processRange = TimeRef(64, 44100);
 			nextDataPointLocation = processRange;
 		}
 		
@@ -164,7 +167,9 @@ private:
 	struct ChannelData {
 		ChannelData() {
 			memory = 0;
+			peakdataDecodeBuffer = 0;
 		}
+		~ChannelData();
 		QString		fileName;
 		QString		normFileName;
 		QFile 		file;
@@ -182,6 +187,7 @@ private:
 	int create_from_scratch();
 	int read_header();
 	int write_header(ChannelData* data);
+	static void calculate_lut_data();
 
 	friend class PeakProcessor;
 	friend class PeakDataReader;
@@ -208,6 +214,14 @@ private:
 	nframes_t read(DecodeBuffer* buffer, nframes_t frameCount);
 };
 
+inline QHash< int, int > * Peak::cache_index_lut()
+{
+	if(chacheIndexLut.isEmpty()) {
+		calculate_lut_data();
+	}
+	return &chacheIndexLut;
+}
+
 
 #endif
 
