@@ -442,7 +442,7 @@ int Sheet::prepare_export(ExportSpecification* spec)
 
 	spec->totalTime = spec->endLocation - spec->startLocation;
 
-// 	PWARN("Render length is: %s",timeref_to_ms_3(spec->totalTime).toAscii().data() );
+// 	PWARN("Render length is: %s",timeref_to_ms_3(spec->totalTime).toLatin1().data() );
 
 	spec->pos = spec->startLocation;
 	spec->progress = 0;
@@ -1003,7 +1003,7 @@ void Sheet::resize_buffer(bool updateArmStatus, nframes_t size)
 	
 	if (updateArmStatus) {
 		apill_foreach(Track* track, Track, m_tracks) {
-			AudioBus* bus = audiodevice().get_capture_bus(track->get_bus_in().toAscii());
+			AudioBus* bus = audiodevice().get_capture_bus(track->get_bus_in().toLatin1());
 			if (bus && track->armed()) {
 				bus->set_monitor_peaks(true);
 			}
