@@ -105,7 +105,7 @@ AudioClipView::AudioClipView(SheetView* sv, TrackView* parent, AudioClip* clip )
 	}
 	
 // 	setFlags(ItemIsSelectable | ItemIsMovable);
-	setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 	setCursor(themer()->get_cursor("AudioClip"));
 }
 
