@@ -58,7 +58,7 @@ PluginView::PluginView(PluginChainView* parent, PluginChain* chain, Plugin* plug
 	
 	calculate_bounding_rect();
 	
-	setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 	setCursor(themer()->get_cursor("Plugin"));
 	
 	connect(m_plugin, SIGNAL(bypassChanged()), this, SLOT(repaint()));
