@@ -79,10 +79,10 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 	and adding of audio processing objects in the audio processing chain.
 
 	<br />
-	The AddRemove Command class has to be used for adding/removing items
+	The AddRemove Command class is to be used for adding/removing items
 	to/from ContextItem objects. <br />This class detects if the add/remove function
 	can be called directly, or in a thread save way, and uses therefore the
-	Tsar class, and the Song object in case it was given as a parameter.<br />
+	Tsar class, and the Sheet object in case it was given as a parameter.<br />
 	See for more information the AddRemove, AudioDevice and Tsar class
 	documentation.
  */
@@ -313,7 +313,8 @@ void Traverso::prepare_audio_device( )
 #else
 	QString driverType = config().get_property("Hardware", "drivertype", "PortAudio").toString();
 #endif
-	QString cardDevice = config().get_property("Hardware", "carddevice", "hw:0").toString();
+        QString cardDevice = config().get_property("Hardware", "carddevice", "default").toString();
+	QString ditherShape = config().get_property("Hardware", "DitherShape", "None").toString();
 	bool capture = config().get_property("Hardware", "capture", 1).toInt();
 	bool playback = config().get_property("Hardware", "playback", 1).toInt();
 
@@ -332,7 +333,7 @@ void Traverso::prepare_audio_device( )
 
 #if defined (ALSA_SUPPORT)
 	if (driverType == "ALSA") {
-		cardDevice = config().get_property("Hardware", "carddevice", "hw:0").toString();
+                cardDevice = config().get_property("Hardware", "carddevice", "default").toString();
 	}
 #endif
 	
@@ -348,7 +349,7 @@ void Traverso::prepare_audio_device( )
 	}
 #endif // end PORTAUDIO_SUPPORT
 	
-	audiodevice().set_parameters(rate, bufferSize, driverType, capture, playback, cardDevice);
+	audiodevice().set_parameters(rate, bufferSize, driverType, capture, playback, cardDevice, ditherShape);
 }
 
 void Traverso::saveState( QSessionManager &  manager)
