@@ -76,6 +76,14 @@ CDWritingDialog::CDWritingDialog( QWidget * parent )
 	connect(refreshButton, SIGNAL(clicked()), this, SLOT(query_devices()));
 	connect(cdDiskExportOnlyCheckBox, SIGNAL(stateChanged(int)), this, SLOT(export_only_changed(int)));
 	
+	
+	m_wodimAvailable = false;
+	
+	// A bit lame way to 'detect' if wodim is installed
+	if (QProcess::execute("wodim") != QProcess::FailedToStart) {
+		m_wodimAvailable = true;
+	}
+	
 	query_devices();
 }
 
@@ -133,6 +141,7 @@ void CDWritingDialog::set_project(Project * project)
 
 void CDWritingDialog::query_devices()
 {
+	PENTER;
 	if ( ! (m_burnprocess->state() == QProcess::NotRunning) ) {
 		printf("query_devices: burnprocess still running!\n");
 		return;
@@ -150,7 +159,13 @@ void CDWritingDialog::query_devices()
 	cdDeviceComboBox->addItem("IOCompactDiscServices");
 	cdDeviceComboBox->addItem("IOCompactDiscServices/2");
 #else
-	m_burnprocess->start(CDRDAO_BIN, QStringList() << "drive-info");
+	// Detect the available devices with wodim if available,
+	// since it seems to work better then cdrdao
+	if (m_wodimAvailable) {
+		m_burnprocess->start("wodim", QStringList() << "--devices");
+	} else {
+		m_burnprocess->start(CDRDAO_BIN, QStringList() << "drive-info");
+	}
 #endif
 }
 
@@ -280,11 +295,11 @@ void CDWritingDialog::cd_render()
 	}
 	
 	// FIXME: We should instead check export wav file timestamps/revision numbers as a dirty test
-	if (! cdAllSongsButton->isChecked() && m_lastSheetExported != m_project->get_current_song_id()) {
+	if (! cdAllSheetsButton->isChecked() && m_lastSheetExported != m_project->get_current_sheet_id()) {
 		m_exportSpec->renderfinished = false;
 	}
 	
-	if (m_wasClosed && m_exportSpec->renderfinished && (m_exportSpec->allSongs == cdAllSongsButton->isChecked()) ) {
+	if (m_wasClosed && m_exportSpec->renderfinished && (m_exportSpec->allSheets == cdAllSheetsButton->isChecked()) ) {
 		
 		if (QMessageBox::question(this, tr("Rerender CD content"), 
 		    		tr("There is already a CD render available.\nShould I re-render the CD content?"), 
@@ -298,7 +313,7 @@ void CDWritingDialog::cd_render()
 	m_wasClosed = false;
 	
 	if ( !	(m_exportSpec->renderfinished && 
-		(m_exportSpec->allSongs == cdAllSongsButton->isChecked()) &&
+		(m_exportSpec->allSheets == cdAllSheetsButton->isChecked()) &&
 		(m_exportSpec->normalize == cdNormalizeCheckBox->isChecked())) ) {
 		
 		m_exportSpec->data_width = 16;
@@ -309,10 +324,10 @@ void CDWritingDialog::cd_render()
 		m_exportSpec->writeToc = true;
 		m_exportSpec->dither_type = GDitherTri;
 		m_exportSpec->src_quality = SRC_SINC_MEDIUM_QUALITY; // SRC_SINC_BEST_QUALITY  SRC_SINC_FASTEST  SRC_ZERO_ORDER_HOLD  SRC_LINEAR
-		if (cdAllSongsButton->isChecked()) {
-			m_exportSpec->allSongs = true;
+		if (cdAllSheetsButton->isChecked()) {
+			m_exportSpec->allSheets = true;
 		} else {
-			m_exportSpec->allSongs = false;
+			m_exportSpec->allSheets = false;
 		}
 		m_exportSpec->normalize = cdNormalizeCheckBox->isChecked();
 		m_exportSpec->isRecording = false;
@@ -334,7 +349,7 @@ void CDWritingDialog::cd_render()
 		
 		disable_ui_interaction();
 		m_project->export_project(m_exportSpec);
-		m_lastSheetExported = m_project->get_current_song_id();
+		m_lastSheetExported = m_project->get_current_sheet_id();
 	} else {
 		if (cdDiskExportOnlyCheckBox->isChecked()) {
 			return;
@@ -369,21 +384,45 @@ void CDWritingDialog::write_to_cd()
 		
 	QString device = get_device(index);
 	QStringList arguments;
-	arguments << "write" << "--device" << device << "-n" << "--eject" << "--driver" << "generic-mmc";
+	QString burnprogram;
 	
-	if (speedComboBox->currentIndex() != 0) {
-		arguments << "--speed" << speedComboBox->currentText().remove("x");
-	}
 	
-	if (simulateCheckBox->isChecked()) {
-		arguments << "--simulate";
-	}
+	// wodim vs cdrecord vs cdrdao?? a lot of fuzz about these, 
+	// but so far cdrdao works for me just fine, so let's continue
+	// using it for the actual burning for now.
+	
+/*	if (m_wodimAvailable) {
+		burnprogram = "wodim";
+		arguments << "-vv";
+		if (simulateCheckBox->isChecked()) {
+			arguments << "-dummy";
+		}
+		arguments << QString("dev=").append(device);
+		arguments << "driveropts=burnfree";
+		arguments << "-dao";
+		arguments << "-eject";
+		if (speedComboBox->currentIndex() != 0) {
+			arguments << "speed=" << speedComboBox->currentText().remove("x");
+		}
+	} else {*/
+		burnprogram = CDRDAO_BIN;
+		arguments << "write" << "--device" << device << "-n" << "--eject" << "--driver" << "generic-mmc";
+		if (speedComboBox->currentIndex() != 0) {
+			arguments << "--speed" << speedComboBox->currentText().remove("x");
+		}
+		if (simulateCheckBox->isChecked()) {
+			arguments << "--simulate";
+		}
+// 	}
 	
 	arguments << m_exportSpec->tocFileName;
+	
+	printf("%s arguments: %s\n", QS_C(burnprogram), QS_C(arguments.join(" ")));
+
 #if defined (Q_WS_MAC)
 	m_burnprocess->start(qApp->applicationDirPath() + "/cdrdao", arguments);
 #else
-	m_burnprocess->start(CDRDAO_BIN, arguments);
+	m_burnprocess->start(burnprogram, arguments);
 #endif
 }
 
@@ -434,50 +473,76 @@ void CDWritingDialog::update_cdburn_status(const QString& message, int type)
 
 void CDWritingDialog::read_standard_output()
 {
+	PENTER;
+	
 	Q_ASSERT(m_burnprocess);
 	
 	if (m_writingState == QUERY_DEVICE) {
-		char buf[1024];
 		
-		while(m_burnprocess->readLine(buf, sizeof(buf)) != -1) {
-			QString data = QString(buf);
-			//printf("%s\n", QS_C(data));
+		QByteArray output = m_burnprocess->readAllStandardOutput();
+		QList<QByteArray> lines = output.split('\n');
+		
+		foreach(QByteArray data, lines) {
+			
+			if (data.isEmpty()) {
+				continue;
+			}
+			
+			printf("%s\n", data.data());
+			
 			if (data.contains("trying to open")) {
 				update_cdburn_status(tr("Trying to access CD Writer ..."), NORMAL_MESSAGE);
 				return;
 			}
+			
 			if (data.contains("Cannot open") || data.contains("Cannot setup")) {
 				update_cdburn_status(tr("Cannot access CD Writer, is it in use ?"), ERROR_MESSAGE);
 				return;
 			}
 #if defined (Q_WS_WIN)
-			if (data.contains(QRegExp("[0-9],[0-9],[0-9]"))) {
+			if (QString(data).contains(QRegExp("[0-9],[0-9],[0-9]"))) {
 #else
-			if (data.contains("/dev/")) {
+			if (data.contains("/dev/") || data.contains("dev=")) {
 #endif
-				QString deviceName;
 				QStringList strlist = QString(data).split(QRegExp("\\s+"));
-				for (int i=1; i<strlist.size(); ++i) {
-					QString token = strlist.at(i);
-					if (token.contains("Rev:")) {
-						break;
-					} else if (token != ":") {
-						deviceName += token + " ";
+				QString deviceName = "No Device Available";
+				QString device = "/no/device/detected";
+				
+				if (m_wodimAvailable) {
+					if (strlist.size() > 5) {
+						deviceName = strlist.at(5) + " ";
+						deviceName = deviceName.remove("'");
+					}
+					if (strlist.size() > 7) {
+						deviceName += strlist.at(7) + "  ";
+						deviceName = deviceName.remove("'");
+					}
+					if (strlist.size() > 2) {
+						device = strlist.at(2);
+						device = device.remove("dev=").remove("'");
+						deviceName += "(" + device + ")";
+					}
+				} else {
+					if (strlist.size() > 1) {
+						deviceName = strlist.at(1) + " ";
+					}
+					if (strlist.size() > 3) {
+						deviceName += strlist.at(3) + "  ";
+					}
+					if (strlist.size() > 0) {
+						device = strlist.at(0);
+						device = device.remove(":");
+						deviceName += "(" + device + ")";
 					}
 				}
-				QString device = strlist.at(0);
-				device = device.remove(":");
-				deviceName += "(" + device + ")";
 				cdDeviceComboBox->addItem(deviceName, device);
 			}
 		}
 		
 		QString cdrdaoDrive = config().get_property("Cdrdao", "drive", "").toString();
-		if (cdrdaoDrive != "") {
-			int index = cdDeviceComboBox->findData(cdrdaoDrive);
-			if (index != -1) {
-				cdDeviceComboBox->setCurrentIndex(index);
-			}
+		int index = cdDeviceComboBox->findData(cdrdaoDrive);
+		if (index >= 0) {
+			cdDeviceComboBox->setCurrentIndex(index);
 		}
 		
 		update_cdburn_status(tr("Information"), NORMAL_MESSAGE);
@@ -611,10 +676,10 @@ void CDWritingDialog::set_was_closed()
 
 QString CDWritingDialog::get_device(int index)
 {
-	#if defined (Q_WS_MAC)
-		return cdDeviceComboBox->currentText();
-	#else
-		return cdDeviceComboBox->itemData(index).toString();
-	#endif
+#if defined (Q_WS_MAC)
+	return cdDeviceComboBox->currentText();
+#else
+	return cdDeviceComboBox->itemData(index).toString();
+#endif
 }
 
