@@ -37,8 +37,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 #include <InputEngine.h>
 #include "Interface.h"
 #include <QDomDocument>
-#include <QPrinter>
-#include <QPrintDialog>
+#include <QtPrintSupport/QPrinter>
+#include <QtPrintSupport/QPrintDialog>
 #include <QTextEdit>
 
 #if defined (JACK_SUPPORT)
@@ -820,13 +820,13 @@ void KeyboardConfigPage::on_printButton_clicked()
 	QString kmap;
 	Interface::instance()->get_keymap(kmap);
 
-	QPrinter printer(QPrinter::ScreenResolution);
-	QPrintDialog printDialog(&printer, Interface::instance());
-	if (printDialog.exec() == QDialog::Accepted) {
-		QTextEdit edit;
-		edit.insertHtml(kmap);
-		edit.document()->print(&printer);
-	}
+//	QPrinter printer(QPrinter::ScreenResolution);
+//	QPrintDialog printDialog(&printer, Interface::instance());
+//	if (printDialog.exec() == QDialog::Accepted) {
+//		QTextEdit edit;
+//		edit.insertHtml(kmap);
+//		edit.document()->print(&printer);
+//	}
 }
 
 
